Reports | OiRA

Topics

# Reports

You can use a report to:

- Provide evidence for supervisory authorities.
- Pass information to the people concerned (workers, safety representatives, employers, experts in occupational safety and health, etc.)
- Monitor and assess whether necessary measures have been introduced.
- Record any revision if circumstances change (new machines, new workers, as a result of findings of any accident investigations, etc.)

You can save the report on your computer and print it. You can also modify it or add more information. Please note that changes made in a report that you have downloaded will NOT be saved in the OiRA tool.

## Report choices

There are different kinds of reports available for different purposes. The selection of reports available for the specific tools depends on decisions taken by the national OiRA partner/tool developer.

The available reports.

### Full report

Format: Word / Office Open XML (.docx) - can be edited by you after download

Provides: all the information and input entered by you throughout the risk assessment process.

Use it to:

- Provide evidence of the risk assessment for supervisory authorities (labour inspectorate).

### Action plan

Format: Excel / Office Open XML (.xlsx) - can be edited by you after download

Provides: information on all measures you have chosen to implement.

Use it to:

- Actively follow up on the implementation of measures that you have chosen
- Manage the problems/risks in your workplace (specific tasks, expertise, responsibilities, deadlines).

### Risks overview

Format: Portable Document Format (.pdf) – can not be edited by you after download

Provides: an overview of the risks identified

Use it to:

- Get a quick overview on the status of risks in your establishment.
- Pass information to the people concerned.
- Monitor whether risks / measures are properly dealt with.

### Measures overview

Format: Portable Document Format (.pdf) - cannot be edited by you after download

Provides: a quick overview of the measures to be implemented.

Use it to:

- Get a quick overview on the status of measures you have decided to implement.
- Pass information to the people concerned.
- Monitor whether risks / measures are properly dealt with.

Scroll to top
Back

## 4-reports.md

More…

- New risk assessment
- Show archived risk assessments
- All types of risk assessments Only regular risk assessments Only contractor risk assessments

Help

Standard search Advanced search